Trait palette::encoding::pixel::RawPixel [−][src]
pub unsafe trait RawPixel<T> {
fn channels(&self) -> usize;
unsafe fn from_raw_parts<'a>(pointer: *const T, length: usize) -> &'a Self;
unsafe fn from_raw_parts_mut<'a>(
pointer: *mut T,
length: usize
) -> &'a mut Self;
fn as_ptr(&self) -> *const T;
fn as_mut_ptr(&mut self) -> *mut T;
}A contiguous sequence of pixel channels.
It’s used when converting to and from raw pixel data and should only be implemented for types with a suitable in-memory representation.
Required methods
fn channels(&self) -> usize[src]
The length of the sequence.
unsafe fn from_raw_parts<'a>(pointer: *const T, length: usize) -> &'a Self[src]
Convert from a pointer and a length.
unsafe fn from_raw_parts_mut<'a>(pointer: *mut T, length: usize) -> &'a mut Self[src]
Convert from a mutable pointer and a length.
fn as_ptr(&self) -> *const T[src]
Convert to a pointer.
fn as_mut_ptr(&mut self) -> *mut T[src]
Convert to a mutable pointer.
Implementations on Foreign Types
impl<T> RawPixel<T> for [T][src]
impl<T> RawPixel<T> for [T][src]Implementors
impl<P: RawPixelSized<T>, T> RawPixel<T> for P[src]
impl<P: RawPixelSized<T>, T> RawPixel<T> for P[src]